pub fn get_cgroup_setup_with_root(
root_path: &Path,
) -> Result<CgroupSetup, GetCgroupSetupError>Expand description
Determines the cgroup setup of the system. Systems typically have one of three setups:
- Unified: Pure cgroup v2 system.
- Legacy: Pure cgroup v1 system.
- Hybrid: Hybrid is basically a cgroup v1 system, except for an additional unified hierarchy which doesn’t have any controllers attached. Resource control can purely be achieved through the cgroup v1 hierarchy, not through the cgroup v2 hierarchy.