pub struct ControllerOpt<'a> {
pub resources: &'a LinuxResources,
pub disable_oom_killer: bool,
pub oom_score_adj: Option<i32>,
pub freezer_state: Option<FreezerState>,
}Expand description
ControllerOpt is given all cgroup controller for applying cgroup configuration.
Fields
resources: &'a LinuxResourcesResources contain cgroup information for handling resource constraints for the container.
disable_oom_killer: boolDisables the OOM killer for out of memory conditions.
oom_score_adj: Option<i32>Specify an oom_score_adj for container.
freezer_state: Option<FreezerState>FreezerState is given to freezer controller for suspending process.