pub struct CpuUsage {
pub usage_total: u64,
pub usage_user: u64,
pub usage_kernel: u64,
pub per_core_usage_total: Vec<u64>,
pub per_core_usage_user: Vec<u64>,
pub per_core_usage_kernel: Vec<u64>,
}Expand description
Reports the cpu usage for a cgroup
Fields
usage_total: u64Cpu time consumed by tasks in total
usage_user: u64Cpu time consumed by tasks in user mode
usage_kernel: u64Cpu time consumed by tasks in kernel mode
per_core_usage_total: Vec<u64>Cpu time consumed by tasks itemized per core
per_core_usage_user: Vec<u64>Cpu time consumed by tasks in user mode itemized per core
per_core_usage_kernel: Vec<u64>Cpu time consumed by tasks in kernel mode itemized per core