pub fn get_available_controllers<P: AsRef<Path>>(
root_path: P,
) -> Result<Vec<ControllerType>, V2UtilError>Expand description
Reads the {root_path}/cgroup.controllers file to get the list of the controllers that are
available in this cgroup
pub fn get_available_controllers<P: AsRef<Path>>(
root_path: P,
) -> Result<Vec<ControllerType>, V2UtilError>Reads the {root_path}/cgroup.controllers file to get the list of the controllers that are
available in this cgroup